@@ -7,7 +7,7 @@ require Exporter;
 use strict;
 use vars qw($VERSION @ISA);
 @ISA = qw(Spreadsheet::ParseExcel::Workbook Exporter);
-$VERSION = '0.01'; # 
+$VERSION = '0.02'; # 
 #==============================================================================
 # Spreadsheet::ParseExcel::SaveParser::Workbook
 #==============================================================================
@@ -27,43 +27,70 @@ sub new($$) {
 # AddWorksheet (for Spreadsheet::ParseExcel::SaveParser)
 #------------------------------------------------------------------------------
 sub AddWorksheet($$%) {
-    my($oThis, $sName, %hAttr) = @_;
+    my($oBook, $sName, %hAttr) = @_;
+    $oBook->AddFormat if($#{$oBook->{Format}}<0);
     $hAttr{Name} ||= $sName;
     my $oWkS = Spreadsheet::ParseExcel::Worksheet->new(%hAttr);
-    $oThis->{Worksheet}[$oThis->{SheetCount}] = $oWkS;
-    $oThis->{SheetCount}++;
-    return $oThis->{SheetCount} - 1;
-}
-#------------------------------------------------------------------------------
-# AddFormat (for Spreadsheet::ParseExcel::SaveParser)
-#------------------------------------------------------------------------------
-sub AddFormat($%){
-    my ($oBook, %hAttr) = @_;
-    push @{$oBook->{Format}}, 
-        Spreadsheet::ParseExcel::Format->new(%hAttr);
-    return $#{$oBook->{Format}};
+    $oBook->{Worksheet}[$oBook->{SheetCount}] = $oWkS;
+    $oBook->{SheetCount}++;
+    return $oBook->{SheetCount} - 1;
 }
 #------------------------------------------------------------------------------
 # AddFont (for Spreadsheet::ParseExcel::SaveParser)
 #------------------------------------------------------------------------------
 sub AddFont($%){
     my ($oBook, %hAttr) = @_;
+    $hAttr{Name}     ||= 'Arial';
+    $hAttr{Height}   ||= 10;
+    $hAttr{Bold}     ||= 0;
+    $hAttr{Italic}   ||= 0;
+    $hAttr{Underline}||= 0;
+    $hAttr{Strikeout}||= 0;
+    $hAttr{Super}    ||= 0;
     push @{$oBook->{Font}}, 
         Spreadsheet::ParseExcel::Font->new(%hAttr);
     return $#{$oBook->{Font}};
 }
 #------------------------------------------------------------------------------
+# AddFormat (for Spreadsheet::ParseExcel::SaveParser)
+#------------------------------------------------------------------------------
+sub AddFormat($%){
+    my ($oBook, %hAttr) = @_;
+    $hAttr{Fill}     ||= [0, 0, 0];
+    $hAttr{BdrStyle} ||= [0, 0, 0, 0];
+    $hAttr{BdrColor} ||= [0, 0, 0, 0];
+    if(!defined($hAttr{Font})) {
+        my $oFont;
+        if(defined $hAttr{FontNo}) {
+            $oFont = $oBook->{Font}[$hAttr{FontNo}];
+        }
+        elsif(!defined $oFont) {
+            if($#{$oBook->{Font}}>=0) {
+                $oFont = $oBook->{Font}[0];
+            }
+            else {
+                my $iNo = $oBook->AddFont;
+                $oFont = $oBook->{Font}[$iNo];
+            }
+        }
+        $hAttr{Font} = $oFont;
+    }
+    push @{$oBook->{Format}}, 
+        Spreadsheet::ParseExcel::Format->new(%hAttr);
+    return $#{$oBook->{Format}};
+}
+#------------------------------------------------------------------------------
 # AddCell (for Spreadsheet::ParseExcel::SaveParser)
 #------------------------------------------------------------------------------
 sub AddCell($$$$$$;$) {
     my($oBook, $iSheet, $iR, $iC, $sVal, $oCell, $sCode)=@_;
     my %rhKey;
-
+    $oCell ||= 0;
     my $iFmt = (UNIVERSAL::isa($oCell, 'Spreadsheet::ParseExcel::Cell'))?
-                $oCell->{FormatNo} : $oCell;
+                $oCell->{FormatNo} : (ref($oCell))? 0: $oCell+0;
     $rhKey{FormatNo} = $iFmt;
     $rhKey{Val}      = $sVal;
-    $rhKey{Code}     = $sCode;
+    $rhKey{Code}     = $sCode || '_native_';
     $oBook->{_CurSheet} = $iSheet;
     Spreadsheet::ParseExcel::_NewCell($oBook, $iR, $iC, %rhKey);
     Spreadsheet::ParseExcel::_SetDimension($oBook, $iR, $iC, $iC);
@@ -91,6 +118,23 @@ sub new($%) {
     return $oThis;
 }
 #------------------------------------------------------------------------------
+# Create
+#------------------------------------------------------------------------------
+sub Create($;$) {
+    my($oThis, $oWkFmt)=@_;
+#0. New $oBook
+    my $oBook = Spreadsheet::ParseExcel::Workbook->new;
+    $oBook->{SheetCount} = 0;
+#2. Ready for format
+    if ($oWkFmt) {
+        $oBook->{FmtClass} = $oWkFmt;
+    }
+    else {
+        $oBook->{FmtClass} = new Spreadsheet::ParseExcel::FmtDefault;
+    }
+    return Spreadsheet::ParseExcel::SaveParser::Workbook->new($oBook);
+}
+#------------------------------------------------------------------------------
 # Parse (for Spreadsheet::ParseExcel::SaveParser)
 #------------------------------------------------------------------------------
 sub Parse($$;$) {
@@ -130,7 +174,6 @@ sub SaveAs($$$){
             $oFmt->set_align($aAlH[$pFmt->{AlignH}]);
             $oFmt->set_align($aAlV[$pFmt->{AlignV}]);
             if($pFmt->{Rotate}==0) {
-                #]
                 $oFmt->set_rotation(0);
             }
             elsif($pFmt->{Rotate}> 0) {  # Mainly ==90
@@ -168,43 +211,78 @@ sub SaveAs($$$){
     for(my $iSheet=0; $iSheet < $oBook->{SheetCount} ; $iSheet++) {
         my $oWkS = $oBook->{Worksheet}[$iSheet];
         my $oWrS = $oWrEx->addworksheet($oWkS->{Name});
-=cmmt
-        $oWrS->set_printinfo( 
-            Landscape    => $oWkS->{Landscape},            # Landscape (0:Horizontal, 1:Vertical)
-            Scale        => $oWkS->{Scale},                # Scale
-            FitWidth     => $oWkS->{FitWidth},             # Pages on fit with width
-            FitHeight    => $oWkS->{FitHeight},            # Pages on fit with height
-            PageFit      => $oWkS->{PageFit},              # Pages on fit
-            PaperSize    => $oWkS->{PaperSize},            # Paper size (8=A3)
+        #Landscape
+        if($oWkS->{Landscape}==0) { # Landscape (0:Horizontal, 1:Vertical)
+            $oWrS->set_landscape();
+        }
+        else {
+            $oWrS->set_portrait();
+        }
+        if(($oWkS->{FitWidth}==1) and ($oWkS->{FitHeight}==1)) {
+            # Pages on fit with width and Heigt
+            $oWrS->fit_to_pages($oWkS->{FitWidth}, $oWkS->{FitHeight});
+            #Print Scale
+            $oWrS->set_print_scale($oWkS->{Scale});
+        }
+        else {
+            #Print Scale
+            $oWrS->set_print_scale($oWkS->{Scale});
+            # Pages on fit with width and Heigt
+            $oWrS->fit_to_pages($oWkS->{FitWidth}, $oWkS->{FitHeight});
+        }
+        # Paper Size
+        $oWrS->set_paper($oWkS->{PaperSize});
+        # Margin
+        $oWrS->set_margin_left($oWkS->{LeftMergin}     / 2.55);
+        $oWrS->set_margin_right($oWkS->{RightMergin}   / 2.55);
+        $oWrS->set_margin_top($oWkS->{TopMergin}       / 2.55);
+        $oWrS->set_margin_bottom($oWkS->{BottomMergin} / 2.55);
+        # HCenter
+        $oWrS->center_horizontally() if($oWkS->{HCenter});
+        # VCenter
+        $oWrS->center_vertically() if($oWkS->{VCenter});
+        # Header, Footer
+        $oWrS->set_header($oWkS->{Header}, $oWkS->{HeaderMergin}/2.55);
+        $oWrS->set_footer($oWkS->{Footer}, $oWkS->{FooterMergin}/2.55);
+        # Print Area
+        if(ref($oBook->{PrintArea}[$iSheet]) eq 'ARRAY') {
+            my $raP;
+            for $raP (@{$oBook->{PrintArea}[$iSheet]}) {
+                $oWrS->print_area(@$raP);
+            }
+        }
+            
+        # Print Title
+        my $raW;
+        foreach $raW (@{$oBook->{PrintTitle}[$iSheet]->{Row}}) {
+            $oWrS->repeat_rows(@$raW);
+        }
+        foreach $raW (@{$oBook->{PrintTitle}[$iSheet]->{Column}}) {
+            $oWrS->repeat_columns(@$raW);
+        }
+        # Print Gridlines
+        if($oWkS->{PrintGrid}==1) {
+            $oWrS->hide_gridlines(0);
+        }
+        else {
+            $oWrS->hide_gridlines(1);
+        }
+        # Print Headings
+        if($oWkS->{PrintHeaders}) {
+            $oWrS->print_row_col_headers();
+        }
+        # Horizontal Page Breaks
+        $oWrS->set_h_pagebreaks(@{$oWkS->{HPageBreak}});
+        # Veritical Page Breaks
+        $oWrS->set_v_pagebreaks(@{$oWkS->{VPageBreak}});
+=pod
+
             PageStart    => $oWkS->{PageStart},            # Page number for start
             UsePage      => $oWkS->{UsePage},              # Use own start page number
-
-            Mergin       => [$oWkS->{LeftMergin},
-                             $oWkS->{RightMergin},
-                             $oWkS->{TopMergin},
-                             $oWkS->{BottomMergin},
-                             $oWkS->{HeaderMergin},
-                             $oWkS->{FooterMergin}, ],      # Mergins(Left,Right,Top,Bottom,Header,Footer)
-            HCenter      => $oWkS->{HCenter},               # Horizontal Center
-            VCenter      => $oWkS->{VCenter},               # Vertical Center
-
-            Header       => $oWkS->{Header},                # Header
-            Footer       => $oWkS->{Footer},                # Footer
-
-            PrintArea    => $oBook->{PrintArea}[$iSheet],
-            PrintTitle   => {Row    => $oBook->{PrintTitle}[$iSheet]->{Row}[0],
-                             Column => $oBook->{PrintTitle}[$iSheet]->{Column}[0]}, 
-                                                            # PrintTitles(Row, Column)
-            PrintGrid    => $oWkS->{PrintGrid},             # Print Gridlines
-            PrintHeaders => $oWkS->{PrintHeaders},          # Print Headings
             NoColor      => $oWkS->{NoColor},               # Print in blcak-white
             Draft        => $oWkS->{Draft},                 # Print in draft mode
             Notes        => $oWkS->{Notes},                 # Print notes
             LeftToRight  => $oWkS->{LeftToRight},           # Left to Right
-
-            HPageBreak   => $oWkS->{HPageBreak},            # Horizontal Page Breaks
-            VPageBreak   => $oWkS->{VPageBreak},            # Veritical Page Breaks
-        );
 =cut
         for(my $iC = $oWkS->{MinCol} ;
                             defined $oWkS->{MaxCol} && $iC <= $oWkS->{MaxCol} ; $iC++) {            
@@ -248,36 +326,63 @@ Spreadsheet::ParseExcel::SaveParser - Expand of Spreadsheet::ParseExcel with Spr
 
 =head1 SYNOPSIS
 
+    #1. Write an Excel file with previous data
     use strict;
     use Spreadsheet::ParseExcel::SaveParser;
     my $oExcel = new Spreadsheet::ParseExcel::SaveParser;
-    my $oBook = $oExcel->Parse('some.xls');
+    my $oBook = $oExcel->Parse('temp.xls');
+    #1.1.Update and Insert Cells
+    my $iFmt = $oBook->{Worksheet}[0]->{Cells}[0][0]->{FormatNo};
+    $oBook->AddCell(0, 0, 0, 'No(UPD)', 
+        $oBook->{Worksheet}[0]->{Cells}[0][0]->{FormatNo});
+    $oBook->AddCell(0, 1, 0, '304', $oBook->{Worksheet}[0]->{Cells}[0][0]);
+    $oBook->AddCell(0, 1, 1, 'Kawai,Takanori', $iFmt);
+    #1.2.add new worksheet
+    my $iWkN = $oBook->AddWorksheet('Test');
+    #1.3 Save
+    $oExcel->SaveAs($oBook, 'temp.xls');  # as the same name
+    $oExcel->SaveAs($oBook, 'temp1.xls'); # another name
 
-    my $oBWr = Spreadsheet::ParseExcel::SaveParser::Workbook->new($oBook);
-    my $oExcel = new Spreadsheet::ParseExcel;
+    #2. Create new Excel file (most simple)
+    use strict;
+    use Spreadsheet::ParseExcel::SaveParser;
+    my $oEx = new Spreadsheet::ParseExcel::SaveParser;
+    my $oBook = $oEx->Create();
+    $oBook->AddFormat;
+    $oBook->AddWorksheet('NewWS');
+    $oBook->AddCell(0, 0, 1, 'New Cell');
+    $oEx->SaveAs($oBook, 'new.xls');
 
-    #1.1 Normal Excel97
-    my $oBook = $oExcel->Parse('Excel/Test97.xls');
-    my($iR, $iC, $oWkS, $oWkC);
-    print "FILE  :", $oBook->{File} , "\n";
-    print "COUNT :", $oBook->{SheetCount} , "\n";
-    print "AUTHOR:", $oBook->{Author} , "\n";
-    for(my $iSheet=0; $iSheet < $oBook->{SheetCount} ; $iSheet++) {
-        $oWkS = $oBook->{Worksheet}[$iSheet];
-        print "--------- SHEET:", $oWkS->{Name}, "\n";
-        for(my $iR = $oWkS->{MinRow} ; 
-                defined $oWkS->{MaxRow} && $iR <= $oWkS->{MaxRow} ; $iR++) {
-            for(my $iC = $oWkS->{MinCol} ;
-                            defined $oWkS->{MaxCol} && $iC <= $oWkS->{MaxCol} ; $iC++) {
-                $oWkC = $oWkS->{Cells}[$iR][$iC];
-                print "( $iR , $iC ) =>", $oWkC->Value, "\n" if($oWkC);
-            }
-        }
-    }
+    #3. Create new Excel file(more complex)
+    #!/usr/local/bin/perl
+    use strict;
+    use Spreadsheet::ParseExcel::SaveParser;
+    my $oEx = new Spreadsheet::ParseExcel::SaveParser;
+    my $oBook = $oEx->Create();
+    my $iF1 = $oBook->AddFont(
+            Name      => 'Arial',
+            Height    => 11,
+            Bold      => 1, #Bold
+            Italic    => 1, #Italic
+            Underline => 0,
+            Strikeout => 0,
+            Super     => 0,
+        );
+    my $iFmt =
+    $oBook->AddFormat(
+        Font => $oBook->{Font}[$iF1],
+        Fill => [1, 10, 0],         # Filled with Red
+                                    # cf. ParseExcel (@aColor)
+        BdrStyle => [0, 1, 1, 0],   #Border Right, Top
+        BdrColor => [0, 11, 0, 0],  # Right->Green
+    );
+    $oBook->AddWorksheet('NewWS');
+    $oBook->AddCell(0, 0, 1, 'Cell', $iFmt);
+    $oEx->SaveAs($oBook, 'new.xls');
 
 =head1 DESCRIPTION
 
-Spreadsheet::ParseExcel makes you to get information from Excel95, Excel97, Excel2000 file.
+Spreadsheet::ParseExcel::SaveParser : Expand of Spreadsheet::ParseExcel with Spreadsheet::WriteExcel
 
 =head2 Functions
 
@@ -285,34 +390,10 @@ Spreadsheet::ParseExcel makes you to get information from Excel95, Excel97, Exce
 
 =item new
 
-I<$oExcel> = new Spreadsheet::ParseExcel(
-                    [ I<CellHandler> => \&subCellHandler, 
-                      I<NotSetCell> => undef | 1,
-                    ]);
+I<$oExcel> = new Spreadsheet::ParseExcel::SaveParser();
 
 Constructor.
 
-
-=over 4
-
-=item CellHandler I<(experimental)>
-
-specify callback function when a cell is detected.
-
-I<subCellHandler> gets arguments like below:
-
-sub subCellHandler (I<$oBook>, I<$iSheet>, I<$iRow>, I<$iCol>, I<$oCell>);
-
-B<CAUTION> : The atributes of Workbook may not be complete.
-This function will be called almost order by rows and columns.
-Take care B<almost>, I<not perfectly>.
-
-=item NotSetCell I<(experimental)>
-
-specify set or not cell values to Workbook object.
-
-=back
-
 =item Parse
 
 I<$oWorkbook> = $oParse->Parse(I<$sFileName> [, I<$oFmt>]);
@@ -324,7 +405,7 @@ if error occurs, returns undef.
 
 =item I<$sFileName>
 
-name of the file to parse
+name of the file to parse (Same as Spreadsheet::ParseExcel)
 
 From 0.12 (with OLE::Storage_Lite v.0.06), 
 scalar reference of file contents (ex. \$sBuff) or 
@@ -332,487 +413,165 @@ IO::Handle object (inclucdng IO::File etc.) are also available.
 
 =item I<$oFmt>
 
-L<"Formatter Class"> to format the value of cells.
+Formatter Class to format the value of cells.
 
 =back
 
-=item ColorIdxToRGB
+=item Create
 
-I<$sRGB> = $oParse->ColorIdxToRGB(I<$iColorIdx>);
+I<$oWorkbook> = $oParse->Create([I<$oFmt>]);
 
-I<ColorIdxToRGB> returns RGB string corresponding to specified color index.
-RGB string has 6 charcters, representing RGB hex value. (ex. red = 'FF0000')
+return new L<"Workbook"> object.
+if error occurs, returns undef.
+
+=over 4
+
+=item I<$oFmt>
+
+Formatter Class to format the value of cells.
+
+=back
+
+=item SaveAs
+
+I<$oWorkbook> = $oParse->SaveAs( $oBook, $sName);
+
+save $oBook image as an Excel file named $sName.
+
+=over 4
+
+=item I<$oBook>
+
+An Excel Workbook object to save.
+
+=back
+
+=item I<$sName>
+
+Name of new Excel file.
 
 =back
 
 =head2 Workbook
 
-I<Spreadsheet::ParseExcel::Workbook>
+I<Spreadsheet::ParseExcel::SaveParser::Workbook>
 
-Workbook class has these properties :
+Workbook is a subclass of Spreadsheet::ParseExcel::Workbook.
+And has these methods :
 
 =over 4
 
-=item File
+=item AddWorksheet
 
-Name of the file
+I<$oWorksheet> = $oBook->AddWorksheet($sName, %hProperty);
 
-=item Author
-
-Author of the file
-
-=item Flag1904
-
-If this flag is on, date of the file count from 1904.
-
-=item Version
-
-Version of the file
-
-=item SheetCount
-
-Numbers of L<"Worksheet"> s in that Workbook
-
-=item Worksheet[SheetNo]
-
-Array of L<"Worksheet">s class
-
-=item PrintArea[SheetNo]
-
-Array of PrintArea array refs.
-
-Each PrintArea is : [ I<StartRow>, I<StartColumn>, I<EndRow>, I<EndColumn>]
-
-=item PrintTitle[SheetNo]
-
-Array of PrintTitle hash refs.
-
-Each PrintTitle is : 
-        { Row => [I<StartRow>, I<EndRow>], 
-          Column => [I<StartColumn>, I<EndColumn>]}
-
-=back
-
-=head2 Worksheet
-
-I<Spreadsheet::ParseExcel::Worksheet>
-
-Worksheet class has these properties:
+Create new Worksheet(Spreadsheet::ParseExcel::Worksheet).
 
 =over 4
 
-=item Name
+=item I<$sName>
 
-Name of that Worksheet
+Name of new Worksheet
 
-=item DefRowHeight
+=item I<$hProperty>
 
-Default height of rows
-
-=item DefColWidth
-
-Default width of columns
-
-=item RowHeight[Row]
-
-Array of row height
-
-=item ColWidth[Col]
-
-Array of column width (undef means DefColWidth)
-
-=item Cells[Row][Col]
-
-Array of L<"Cell">s infomation in the worksheet
-
-=item Landscape
-
-Print in horizontal(0) or vertical (1).
-
-=item Scale
-
-Print scale.
-
-=item FitWidth
-
-Number of pages with fit in width. 
-
-=item FitHeight
-
-Number of pages with fit in height.
-
-=item PageFit
-
-Print with fit (or not).
-
-=item PaperSize
-
-Papar size. The value is like below:
-
-  Letter               1, LetterSmall          2, Tabloid              3 ,
-  Ledger               4, Legal                5, Statement            6 ,
-  Executive            7, A3                   8, A4                   9 ,
-  A4Small             10, A5                  11, B4                  12 ,
-  B5                  13, Folio               14, Quarto              15 ,
-  10x14               16, 11x17               17, Note                18 ,
-  Envelope9           19, Envelope10          20, Envelope11          21 ,
-  Envelope12          22, Envelope14          23, Csheet              24 ,
-  Dsheet              25, Esheet              26, EnvelopeDL          27 ,
-  EnvelopeC5          28, EnvelopeC3          29, EnvelopeC4          30 ,
-  EnvelopeC6          31, EnvelopeC65         32, EnvelopeB4          33 ,
-  EnvelopeB5          34, EnvelopeB6          35, EnvelopeItaly       36 ,
-  EnvelopeMonarch     37, EnvelopePersonal    38, FanfoldUS           39 ,
-  FanfoldStdGerman    40, FanfoldLegalGerman  41, User                256
-
-=item PageStart
-
-Start page number.
-
-=item UsePage
-
-Use own start page number (or not).
-
-=item LeftMergin, RightMergin, TopMergin, BottomMergin, HeaderMergin, FooterMergin
-
-Mergins for left, right, top, bottom, header and footer.
-
-=item HCenter
-
-Print in horizontal center (or not)
-
-=item VCenter
-
-Print in vertical center  (or not)
-
-=item Header
-
-Content of print header.
-Please refer Excel Help.
-
-=item Footer
-
-Content of print footer.
-Please refer Excel Help.
-
-=item PrintGrid
-
-Print with Gridlines (or not)
-
-=item PrintHeaders
-
-Print with headings (or not)
-
-=item NoColor
-
-Print in black-white (or not).
-
-=item Draft
-
-Print in draft mode (or not).
-
-=item Notes
-
-Print with notes (or not).
-
-=item LeftToRight
-
-Print left to right(0) or top to down(1).
-
-=item HPageBreak
-
-Array ref of horizontal page breaks.
-
-=item VPageBreak
-
-Array ref of vertical page breaks.
-
-=item MergedArea
-
-Array ref of merged areas.
-Each merged area is : [ I<StartRow>, I<StartColumn>, I<EndRow>, I<EndColumn>]
+Property of new Worksheet.
 
 =back
 
-=head2 Cell
+=item AddFont
 
-I<Spreadsheet::ParseExcel::Cell>
+I<$oWorksheet> = $oBook->AddFont(%hProperty);
 
-Cell class has these properties:
+Create new Font(Spreadsheet::ParseExcel::Font).
 
 =over 4
 
-=item Value
+=item I<$hProperty>
 
-I<Method>
-Formatted value of that cell
-
-=item Val
-
-Original Value of that cell
-
-=item Type
-
-Kind of that cell ('Text', 'Numeric', 'Date')
-
-=item Code
-
-Character code of that cell (undef, 'ucs2', '_native_')
-undef tells that cell seems to be ascii.
-'_native_' tells that cell seems to be 'sjis' or something like that.
-
-=item Format
-
-L<"Format"> for that cell.
-
-=item Merged
-
-That cells is merged (or not).
-
-=item Rich
-
-Array ref of font informations about each characters.
-
-Each entry has : [ I<Start Position>, I<Font Object>]
-
-For more information please refer sample/dmpExR.pl
+Property of new Worksheet.
 
 =back
 
-=head2 Format
+=item AddFormat
 
-I<Spreadsheet::ParseExcel::Format>
+I<$oWorksheet> = $oBook->AddFormat(%hProperty);
 
-Format class has these properties:
+Create new Format(Spreadsheet::ParseExcel::Format).
 
 =over 4
 
-=item Font
+=item I<$hProperty>
 
-L<"Font"> object for that Format.
-
-=item AlignH
-
-Horizontal Alignment.
-
-  0: (standard), 1: left,       2: center,     3: right,      
-  4: fill ,      5: justify,    7:equal_space  
-
-B<Notice:> 6 may be I<merge> but it seems not to work.
-
-=item AlignV
-
-Vertical Alignment.
-
-    0: top,  1: vcenter, 2: bottom, 3: vjustify, 4: vequal_space
-
-=item Indent
-
-Number of indent
-
-=item Wrap
-
-Wrap (or not).
-
-=item Shrink
-
-Display in shrinking (or not)
-
-=item Rotate
-
-In Excel97, 2000      : degrees of string rotation.
-In Excel95 or earlier : 0: No rotation, 1: Top down, 2: 90 degrees anti-clockwise, 
-                        3: 90 clockwise
-
-=item JustLast
-
-JustLast (or not).
-I<I have never seen this attribute.>
-
-=item ReadDir
-
-Direction for read.
-
-=item BdrStyle
-
-Array ref of boder styles : [I<Left>, I<Right>, I<Top>, I<Bottom>]
-
-=item BdrColor
-
-Array ref of boder color indexes : [I<Left>, I<Right>, I<Top>, I<Bottom>]
-
-=item BdrDiag
-
-Array ref of diag boder kind, style and color index : [I<Kind>, I<Style>, I<Color>]
-  Kind : 0: None, 1: Right-Down, 2:Right-Up, 3:Both
-
-=item Fill
-
-Array ref of fill pattern and color indexes : [I<Pattern>, I<Front Color>, I<Back Color>]
-
-=item Lock
-
-Locked (or not).
-
-=item Hidden
-
-Hiddedn (or not).
-
-=item Style
-
-Style format (or Cell format)
+Property of new Format.
 
 =back
 
-=head2 Font
+=item AddCell
 
-I<Spreadsheet::ParseExcel::Font>
+I<$oWorksheet> = $oBook->AddCell($iWorksheet, $iRow, $iCol, $sVal, $iFormat [, $sCode]);
 
-Format class has these properties:
+Create new Cell(Spreadsheet::ParseExcel::Cell).
 
 =over 4
 
-=item Name
+=item I<$iWorksheet>
 
-Name of that font.
-
-=item Bold
-
-Bold (or not).
-
-=item Italic
-
-Italic (or not).
-
-=item Height
-
-Size (height) of that font.
-
-=item Underline
-
-Underline (or not).
-
-=item UnderlineStyle
-
-0: None, 1: Single, 2: Double, 0x21: Single(Account), 0x22: Double(Account)
-
-=item Color
-
-Color index for that font.
-
-=item Strikeout
-
-Strikeout (or not).
-
-=item Super
-
-0: None, 1: Upper, 2: Lower
+Number of Worksheet
 
 =back
 
-=head1 Formatter class
-
-I<Spreadsheet::ParseExcel::Fmt*>
-
-Formatter class will convert cell data.
-
-Spreadsheet::ParseExcel includes 2 formatter classes: FmtDefault and FmtJapanese. 
-You can create your own FmtClass as you like.
-
-Formatter class(Spreadsheet::ParseExcel::Fmt*) should provide these functions:
-
 =over 4
 
-=item ChkType($oSelf, $iNumeric, $iFmtIdx)
+=item I<$iRow>
 
-tells type of the cell that has specified value.
-
-=over 8
-
-=item $oSelf
-
-Formatter itself
-
-=item $iNumeric
-
-If on, the value seems to be number
-
-=item $iFmtIdx
-
-Format index number of that cell
+Number of row
 
 =back
 
-=item TextFmt($oSelf, $sText, $sCode)
+=over 4
 
-converts original text into applicatable for Value.
+=item I<$sVal>
 
-=over 8
-
-=item $oSelf
-
-Formatter itself
-
-=item $sText
-
-Original text
-
-=item $sCode
-
-Character code of Original text
+Value of the cell.
 
 =back
 
-=item ValFmt($oSelf, $oCell, $oBook) 
+=over 4
 
-converts original value into applicatable for Value.
+=item I<$iFormat>
 
-=over 8
+Number of format for use. To specify just same as another cell,
+you can set it like below:
 
-=item $oSelf
+ex.
 
-Formatter itself
-
-=item $oCell
-
-Cell object
-
-=item $oBook
-
-Workbook object
+  $oCell=$oWorksheet->{Cells}[0][0]; #Just a sample
+  $oWorksheet->AddCell(0, 1, 0, 'New One', $oCell->{FormatNo});
+    #or 
+  $oWorksheet->AddCell(0, 1, 0, 'New One', $oCell);
 
 =back
 
-=item FmtString($oSelf, $oCell, $oBook)
+=over 4
 
-get format string for the I<$oCell>.
+=item I<$sCode>
 
-=over 8
-
-=item $oSelf
-
-Formatter itself
-
-=item $oCell
-
-Cell object
-
-=item $oBook
-
-WorkBook object contains that cell
+  Character code
 
 =back
 
 =back
 
-=head1 KNOWN PROBLEM
+=head1 MORE INFORMATION
 
-This module can not get the values of fomulas in 
-Excel files made with Spreadsheet::WriteExcel.
-Normaly (ie. By Excel application), formula has the result with it.
-But Spreadsheet::WriteExcel writes formula with no result.
-If you set your Excel application "Auto Calculation" off.
-(maybe [Tool]-[Option]-[Calculation] or something)
-You will see the same result.
+Please visit my Wiki page.
+ I'll add sample at :
+    http://www.hippo2000.info/cgi-bin/KbWikiE/KbWiki.pl
+
+=head1 Known Problem
+
+-Only last print area will remain. (Others will be removed)
 
 =head1 AUTHOR
 
@@ -829,7 +588,7 @@ This module is based on herbert within OLE::Storage and XLHTML.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000-2001 Kawai Takanori and Nippon-RAD Co. OP Division
+Copyright (c) 2000-2002 Kawai Takanori and Nippon-RAD Co. OP Division
 All rights reserved.
 
 You may distribute under the terms of either the GNU General Public
